Regularizers
============
.. automodapi:: pykeen.regularizers
    :no-heading:
    :headings: --
    :skip: Regularizer

Base Classes
------------
.. autoclass:: pykeen.regularizers.Regularizer
    :members:
    :exclude-members: to
